@@ -5,7 +5,7 @@ from KRNG import RNGs
 
 def main():
     '''generate a Kitten based random number'''
-    sys.stdout.write(RNGs.KRN())
+    sys.stdout.write(str(RNGs.KRN()))
 
 if __name__ == "__main__":
     main()
\ No newline at end of file
